{% load static %}

<script src="{% static 'assets/js/plugins/popper.min.js' %}"></script>
<script src="{% static 'assets/js/plugins/simplebar.min.js' %}"></script>
<script src="{% static 'assets/js/plugins/bootstrap.min.js' %}"></script>
<script src="{% static 'assets/js/config.js' %}"></script>
<script src="{% static 'assets/js/pcoded.js' %}"></script>
<script src="{% static 'assets/js/layoutTheme.js' %}"></script>