{% extends 'layouts/auth_base.html' %}
{% load static %}

{% block title %} Login {% endblock title %}

{% block content %}
  <div class="auth-main">
    <div class="auth-wrapper v3">
      <div class="auth-form">
        <div class="card my-5">
          <div class="card-body">
            <a href="#" class="d-flex justify-content-center">
              <img src="{% static 'assets/images/logo-dark.svg' %}" />
            </a>
            <div class="row">
              <div class="d-flex justify-content-center">
                <div class="auth-header">
                  <h2 class="text-secondary mt-5"><b>Password Changed</b></h2>
                  <p class="f-16 mt-2">Your password has been changed successfully.</p>
                </div>
              </div>
            </div>
            <hr />
            <h5 class="text-decoration-underline">
              <a class="ms-2" href="/">Back to home</a>
            </h5>
          </div>
        </div>
      </div>
    </div>
  </div>
{% endblock content %}
