<footer class="pc-footer">
  <div class="footer-wrapper container-fluid">
    <div class="row">
      <div class="col my-1">
        <p class="m-0">
          &copy; <a href="https://codedthemes.com/?ref=appseed" target="_blank">Codedthemes</a> - Coded by AppSeed.
        </p>
      </div>
      <div class="col-auto my-1">
        <ul class="list-inline footer-link mb-0">
          <li class="list-inline-item"><a target="_blank" href="https://github.com/app-generator/django-admin-berry" target="_blank">Theme</a></li>
          <li class="list-inline-item"><a target="_blank" href="https://appseed.us/product/berry-dashboard/django/" target="_blank">Berry Django</a></li>
          <li class="list-inline-item"><a target="_blank" href="https://appseed.us/support/" target="_blank">Support</a></li>
        </ul>
      </div>
    </div>
  </div>
</footer>
