{% extends "layouts/base.html" %}
{% load i18n admin_urls %}

{% block breadcrumbs %}
    <div class="d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center py-4">
        <div class="d-block mb-4 mb-md-0">
            <nav aria-label="breadcrumb" class="d-none d-md-inline-block">
                <ol class="breadcrumb breadcrumb-dark breadcrumb-transparent">
                    <li class="breadcrumb-item">
                        <a href="{% url 'admin:index' %}">
                            <svg class="icon icon-xxs" fill="none" stroke="currentColor" viewBox="0 0 24 24"
                                 xmlns="http://www.w3.org/2000/svg">
                                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2"
                                      d="M3 12l2-2m0 0l7-7 7 7M5 10v10a1 1 0 001 1h3m10-11l2 2m-2-2v10a1 1 0 01-1 1h-3m-6 0a1 1 0 001-1v-4a1 1 0 011-1h2a1 1 0 011 1v4a1 1 0 001 1m-6 0h6"></path>
                            </svg>
                        </a>
                    </li>
                    <li class="breadcrumb-item">
                      <a href="{% url 'admin:app_list' opts.app_config.label %}">
                        {{ opts.app_config.verbose_name }}
                      </a>
                    </li>

                    <li class="breadcrumb-item">
                        <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
                    </li>

                    <li class="breadcrumb-item">
                        <a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a>
                    </li>

                    <li class="breadcrumb-item">{% trans 'History' %}</li>
                </ol>
            </nav>
        </div>
    </div>
{% endblock %}

{% block content %}
<div class="pc-container">
    <div class="pc-content">
        <div class="row">
            <div class="col-md-12">
                <div class="card">
                    <div class="card-body">
                        {% if action_list %}
                            <div class="table-responsive" style="overflow: hidden;">
                                <table class="table tablesorter {{ direction.panel }}">
                                    <thead class="text-primary">
                                    <tr>
                                        <th scope="col">{% trans 'User' %}</th>
                                        <th scope="col">{% trans 'Action' %}</th>
                                        <th scope="col">{% trans 'Date/time' %}</th>
                                    </tr>
                                    </thead>
                                    <tbody>
                                    {% for action in action_list %}
                                        <tr>
                                            <td>{{ action.user.get_username }}{% if action.user.get_full_name %} (
                                                {{ action.user.get_full_name }}){% endif %}</td>
                                            <td>{{ action.get_change_message }}</td>
                                            <th scope="row">{{ action.action_time|date:"DATETIME_FORMAT" }}</th>
                                        </tr>
                                    {% endfor %}
                                    </tbody>
                                </table>
                            </div>
                        {% else %}
                            <p>{% trans "This object doesn't have a change history. It probably wasn't added via this admin site." %}</p>
                        {% endif %}
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}
