{% extends 'layouts/auth_base.html' %}
{% load static %}

{% block title %} Login {% endblock title %}

{% block content %}
  <div class="auth-main">
    <div class="auth-wrapper v3">
      <div class="auth-form">
        <div class="card my-5">
          <div class="card-body">
            <a href="#" class="d-flex justify-content-center">
              <img src="{% static 'assets/images/logo-dark.svg' %}" />
            </a>
            <div class="row">
              <div class="d-flex justify-content-center">
                <div class="auth-header">
                  <h2 class="text-secondary mt-5"><b>Change Password</b></h2>
                  <p class="f-16 mt-2">Enter new password.</p>
                </div>
              </div>
            </div>
            <form method="post">
              {% csrf_token %}

              {% if form.non_field_errors %}
                {% for error in form.non_field_errors %}
                  <span class="text-danger">{{ error }}</span>
                {% endfor %}
              {% endif %}

              {% for field in form %}
              <div class="form-floating mb-3">
                {{field}}
                <label for="floatingInput">{{ field.label }}</label>
              </div>
              <span class="text-danger">{{ field.errors }}</span>
              {% endfor %}
              <div class="d-grid mt-4">
                <button type="submit" class="btn btn-secondary">Change</button>
              </div>
            </form>
            <hr />
            <h5 class="text-decoration-underline">
              <a class="ms-2" href="/">Cancel</a>
            </h5>
          </div>
        </div>
      </div>
    </div>
  </div>
{% endblock content %}
