<!DOCTYPE html>
{% load static %}
<html lang="en">
<head>
  <title>{% block title %}{% endblock title %} | Berry Bootstrap 5 Admin Template</title>
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=0, minimal-ui" />
  <meta http-equiv="X-UA-Compatible" content="IE=edge" />
  <meta
    name="description"
    content="Berry is made using Bootstrap 5 design framework. Download the free admin template & use it for your project."
  />
  <meta name="keywords" content="Berry, Dashboard UI Kit, Bootstrap 5, Admin Template, Admin Dashboard, CRM, CMS, Bootstrap Admin Template" />
  <meta name="author" content="CodedThemes" />

  {% include 'includes/styles.html' %}

  {% block extrastyle %}{% endblock extrastyle %}

</head>
<body>
  {% block loader %}
    {% include 'includes/loader.html' %}
  {% endblock loader %}

  {% block content %}{% endblock content %}

  {% include 'includes/scripts.html' %}

  {% block extra_js %}{% endblock extra_js %}
</body>
</html>