{% extends 'layouts/base.html' %}
{% load static %}

{% block title %} Tabler Icons Set {% endblock title %}

{% block content %}
  <div class="row">
    <!--[ fontawsome-icon ] start-->
    <div class="col-sm-12">
      <div class="card">
        <div class="card-header">
          <h5>Tabler</h5>
          <p>Use icon with <code>&lt;i class="&lt;&lt; Copied code &gt;&gt;"&gt;</code> in you html code </p>
        </div>
        <div class="card-body text-center">
          <div class="row justify-content-center">
            <div class="col-sm-6">
              <input type="text" id="icon-search" class="form-control mb-4" placeholder="search . . " />
            </div>
          </div>
          <div class="i-main" id="icon-wrapper"></div>
        </div>
      </div>
    </div>
    <!--[ fontawsome-icon ] end-->
  </div>
  <!--[ Main Content ] end-->
{% endblock content %}

{% block extra_js %}
  <!-- [Page Specific JS] start -->
  <script src="{% static 'assets/js/plugins/clipboard.min.js' %}"></script>
  <script type="text/javascript">
    var icon_list = [
      'ti-2fa',
      'ti-3d-cube-sphere',
      'ti-a-b',
      'ti-access-point',
      'ti-access-point-off',
      'ti-accessible',
      'ti-activity',
      'ti-ad',
      'ti-ad-2',
      'ti-adjustments',
      'ti-adjustments-alt',
      'ti-adjustments-horizontal',
      'ti-aerial-lift',
      'ti-affiliate',
      'ti-alarm',
      'ti-alert-circle',
      'ti-alert-octagon',
      'ti-alert-triangle',
      'ti-alien',
      'ti-align-center',
      'ti-align-justified',
      'ti-align-left',
      'ti-align-right',
      'ti-ambulance',
      'ti-anchor',
      'ti-angle',
      'ti-antenna-bars-1',
      'ti-antenna-bars-2',
      'ti-antenna-bars-3',
      'ti-antenna-bars-4',
      'ti-antenna-bars-5',
      'ti-aperture',
      'ti-apple',
      'ti-apps',
      'ti-archive',
      'ti-arrow-back',
      'ti-arrow-back-up',
      'ti-arrow-bar-down',
      'ti-arrow-bar-left',
      'ti-arrow-bar-right',
      'ti-arrow-bar-to-down',
      'ti-arrow-bar-to-left',
      'ti-arrow-bar-to-right',
      'ti-arrow-bar-to-up',
      'ti-arrow-bar-up',
      'ti-arrow-big-down',
      'ti-arrow-big-left',
      'ti-arrow-big-right',
      'ti-arrow-big-top',
      'ti-arrow-bottom-bar',
      'ti-arrow-bottom-circle',
      'ti-arrow-bottom-square',
      'ti-arrow-bottom-tail',
      'ti-arrow-down',
      'ti-arrow-down-circle',
      'ti-arrow-down-left',
      'ti-arrow-down-left-circle',
      'ti-arrow-down-right',
      'ti-arrow-down-right-circle',
      'ti-arrow-forward',
      'ti-arrow-forward-up',
      'ti-arrow-left',
      'ti-arrow-left-bar',
      'ti-arrow-left-circle',
      'ti-arrow-left-square',
      'ti-arrow-left-tail',
      'ti-arrow-loop-left',
      'ti-arrow-loop-right',
      'ti-arrow-narrow-down',
      'ti-arrow-narrow-left',
      'ti-arrow-narrow-right',
      'ti-arrow-narrow-up',
      'ti-arrow-ramp-left',
      'ti-arrow-ramp-right',
      'ti-arrow-right',
      'ti-arrow-right-bar',
      'ti-arrow-right-circle',
      'ti-arrow-right-square',
      'ti-arrow-right-tail',
      'ti-arrow-top-bar',
      'ti-arrow-top-circle',
      'ti-arrow-top-square',
      'ti-arrow-top-tail',
      'ti-arrow-up',
      'ti-arrow-up-circle',
      'ti-arrow-up-left',
      'ti-arrow-up-left-circle',
      'ti-arrow-up-right',
      'ti-arrow-up-right-circle',
      'ti-arrow-wave-left-down',
      'ti-arrow-wave-left-up',
      'ti-arrow-wave-right-down',
      'ti-arrow-wave-right-up',
      'ti-arrows-diagonal',
      'ti-arrows-diagonal-2',
      'ti-arrows-double-ne-sw',
      'ti-arrows-double-nw-se',
      'ti-arrows-double-se-nw',
      'ti-arrows-double-sw-ne',
      'ti-arrows-down',
      'ti-arrows-down-up',
      'ti-arrows-horizontal',
      'ti-arrows-join',
      'ti-arrows-join-2',
      'ti-arrows-left',
      'ti-arrows-left-down',
      'ti-arrows-left-right',
      'ti-arrows-maximize',
      'ti-arrows-minimize',
      'ti-arrows-right',
      'ti-arrows-right-down',
      'ti-arrows-right-left',
      'ti-arrows-sort',
      'ti-arrows-split',
      'ti-arrows-split-2',
      'ti-arrows-up',
      'ti-arrows-up-down',
      'ti-arrows-up-left',
      'ti-arrows-up-right',
      'ti-arrows-vertical',
      'ti-artboard',
      'ti-aspect-ratio',
      'ti-at',
      'ti-atom',
      'ti-atom-2',
      'ti-award',
      'ti-backhoe',
      'ti-backspace',
      'ti-ball-american-football',
      'ti-ball-basketball',
      'ti-ball-bowling',
      'ti-ball-football',
      'ti-ball-football-off',
      'ti-ball-tennis',
      'ti-ball-volleyball',
      'ti-ban',
      'ti-bandage',
      'ti-barcode',
      'ti-basket',
      'ti-battery',
      'ti-battery-1',
      'ti-battery-2',
      'ti-battery-3',
      'ti-battery-4',
      'ti-battery-automotive',
      'ti-battery-charging',
      'ti-battery-off',
      'ti-bed',
      'ti-bell',
      'ti-bell-minus',
      'ti-bell-off',
      'ti-bell-plus',
      'ti-bell-ringing',
      'ti-bell-ringing-2',
      'ti-bell-x',
      'ti-bike',
      'ti-binary',
      'ti-biohazard',
      'ti-blockquote',
      'ti-bluetooth',
      'ti-bluetooth-connected',
      'ti-bluetooth-off',
      'ti-bold',
      'ti-bolt',
      'ti-bolt-off',
      'ti-bone',
      'ti-book',
      'ti-bookmark',
      'ti-bookmark-off',
      'ti-bookmarks',
      'ti-border-all',
      'ti-border-bottom',
      'ti-border-horizontal',
      'ti-border-inner',
      'ti-border-left',
      'ti-border-none',
      'ti-border-outer',
      'ti-border-radius',
      'ti-border-right',
      'ti-border-style',
      'ti-border-style-2',
      'ti-border-top',
      'ti-border-vertical',
      'ti-bottle',
      'ti-box',
      'ti-box-margin',
      'ti-box-model',
      'ti-box-model-2',
      'ti-box-multiple',
      'ti-box-multiple-0',
      'ti-box-multiple-1',
      'ti-box-multiple-2',
      'ti-box-multiple-3',
      'ti-box-multiple-4',
      'ti-box-multiple-5',
      'ti-box-multiple-6',
      'ti-box-multiple-7',
      'ti-box-multiple-8',
      'ti-box-multiple-9',
      'ti-box-padding',
      'ti-braces',
      'ti-brackets',
      'ti-brand-airbnb',
      'ti-brand-android',
      'ti-brand-apple',
      'ti-brand-apple-arcade',
      'ti-brand-appstore',
      'ti-brand-asana',
      'ti-brand-behance',
      'ti-brand-bing',
      'ti-brand-bitbucket',
      'ti-brand-booking',
      'ti-brand-chrome',
      'ti-brand-codepen',
      'ti-brand-codesandbox',
      'ti-brand-css3',
      'ti-brand-deviantart',
      'ti-brand-discord',
      'ti-brand-disqus',
      'ti-brand-docker',
      'ti-brand-dribbble',
      'ti-brand-edge',
      'ti-brand-facebook',
      'ti-brand-figma',
      'ti-brand-firefox',
      'ti-brand-flickr',
      'ti-brand-foursquare',
      'ti-brand-framer',
      'ti-brand-github',
      'ti-brand-gitlab',
      'ti-brand-google',
      'ti-brand-google-analytics',
      'ti-brand-google-drive',
      'ti-brand-google-play',
      'ti-brand-gravatar',
      'ti-brand-hipchat',
      'ti-brand-html5',
      'ti-brand-instagram',
      'ti-brand-javascript',
      'ti-brand-kickstarter',
      'ti-brand-kotlin',
      'ti-brand-linkedin',
      'ti-brand-medium',
      'ti-brand-messenger',
      'ti-brand-netflix',
      'ti-brand-open-source',
      'ti-brand-opera',
      'ti-brand-pagekit',
      'ti-brand-patreon',
      'ti-brand-paypal',
      'ti-brand-pinterest',
      'ti-brand-pocket',
      'ti-brand-producthunt',
      'ti-brand-python',
      'ti-brand-reddit',
      'ti-brand-safari',
      'ti-brand-sass',
      'ti-brand-sentry',
      'ti-brand-shazam',
      'ti-brand-sketch',
      'ti-brand-skype',
      'ti-brand-slack',
      'ti-brand-snapchat',
      'ti-brand-soundcloud',
      'ti-brand-spotify',
      'ti-brand-steam',
      'ti-brand-stripe',
      'ti-brand-tabler',
      'ti-brand-tailwind',
      'ti-brand-telegram',
      'ti-brand-tidal',
      'ti-brand-tiktok',
      'ti-brand-tinder',
      'ti-brand-tumblr',
      'ti-brand-twitch',
      'ti-brand-twitter',
      'ti-brand-unsplash',
      'ti-brand-vercel',
      'ti-brand-vimeo',
      'ti-brand-vk',
      'ti-brand-whatsapp',
      'ti-brand-windows',
      'ti-brand-yahoo',
      'ti-brand-ycombinator',
      'ti-brand-youtube',
      'ti-briefcase',
      'ti-brightness',
      'ti-brightness-2',
      'ti-brightness-down',
      'ti-brightness-half',
      'ti-brightness-up',
      'ti-browser',
      'ti-brush',
      'ti-bucket',
      'ti-bug',
      'ti-building',
      'ti-building-arch',
      'ti-building-bank',
      'ti-building-bridge',
      'ti-building-bridge-2',
      'ti-building-carousel',
      'ti-building-castle',
      'ti-building-church',
      'ti-building-community',
      'ti-building-cottage',
      'ti-building-factory',
      'ti-building-fortress',
      'ti-building-hospital',
      'ti-building-lighthouse',
      'ti-building-monument',
      'ti-building-pavilon',
      'ti-building-skyscraper',
      'ti-building-store',
      'ti-building-warehouse',
      'ti-bulb',
      'ti-bulb-off',
      'ti-bulldozer',
      'ti-bus',
      'ti-businessplan',
      'ti-calculator',
      'ti-calendar',
      'ti-calendar-event',
      'ti-calendar-minus',
      'ti-calendar-off',
      'ti-calendar-plus',
      'ti-calendar-stats',
      'ti-calendar-time',
      'ti-camera',
      'ti-camera-minus',
      'ti-camera-off',
      'ti-camera-plus',
      'ti-camera-rotate',
      'ti-camera-selfie',
      'ti-candy',
      'ti-capture',
      'ti-car',
      'ti-car-crane',
      'ti-caravan',
      'ti-cardboards',
      'ti-caret-down',
      'ti-caret-left',
      'ti-caret-right',
      'ti-caret-up',
      'ti-cash',
      'ti-cash-banknote',
      'ti-cash-banknote-off',
      'ti-cast',
      'ti-ce',
      'ti-certificate',
      'ti-charging-pile',
      'ti-chart-arcs',
      'ti-chart-arcs-3',
      'ti-chart-area',
      'ti-chart-area-line',
      'ti-chart-arrows',
      'ti-chart-arrows-vertical',
      'ti-chart-bar',
      'ti-chart-bubble',
      'ti-chart-candle',
      'ti-chart-circles',
      'ti-chart-donut',
      'ti-chart-donut-2',
      'ti-chart-donut-3',
      'ti-chart-donut-4',
      'ti-chart-dots',
      'ti-chart-infographic',
      'ti-chart-line',
      'ti-chart-pie',
      'ti-chart-pie-2',
      'ti-chart-pie-3',
      'ti-chart-pie-4',
      'ti-chart-radar',
      'ti-check',
      'ti-checkbox',
      'ti-checks',
      'ti-cheese',
      'ti-chevron-down',
      'ti-chevron-down-left',
      'ti-chevron-down-right',
      'ti-chevron-left',
      'ti-chevron-right',
      'ti-chevron-up',
      'ti-chevron-up-left',
      'ti-chevron-up-right',
      'ti-chevrons-down',
      'ti-chevrons-down-left',
      'ti-chevrons-down-right',
      'ti-chevrons-left',
      'ti-chevrons-right',
      'ti-chevrons-up',
      'ti-chevrons-up-left',
      'ti-chevrons-up-right',
      'ti-christmas-tree',
      'ti-circle',
      'ti-circle-0',
      'ti-circle-1',
      'ti-circle-2',
      'ti-circle-3',
      'ti-circle-4',
      'ti-circle-5',
      'ti-circle-6',
      'ti-circle-7',
      'ti-circle-8',
      'ti-circle-9',
      'ti-circle-check',
      'ti-circle-dashed',
      'ti-circle-dotted',
      'ti-circle-half',
      'ti-circle-half-vertical',
      'ti-circle-minus',
      'ti-circle-off',
      'ti-circle-plus',
      'ti-circle-square',
      'ti-circle-x',
      'ti-circles',
      'ti-clear-all',
      'ti-clear-formatting',
      'ti-click',
      'ti-clipboard',
      'ti-clipboard-check',
      'ti-clipboard-list',
      'ti-clipboard-x',
      'ti-clock',
      'ti-cloud',
      'ti-cloud-download',
      'ti-cloud-fog',
      'ti-cloud-off',
      'ti-cloud-rain',
      'ti-cloud-snow',
      'ti-cloud-storm',
      'ti-cloud-upload',
      'ti-code',
      'ti-code-minus',
      'ti-code-plus',
      'ti-coffee',
      'ti-coin',
      'ti-color-picker',
      'ti-color-swatch',
      'ti-column-insert-left',
      'ti-column-insert-right',
      'ti-columns',
      'ti-comet',
      'ti-command',
      'ti-compass',
      'ti-confetti',
      'ti-container',
      'ti-contrast',
      'ti-cookie',
      'ti-copy',
      'ti-copyleft',
      'ti-copyright',
      'ti-corner-down-left',
      'ti-corner-down-left-double',
      'ti-corner-down-right',
      'ti-corner-down-right-double',
      'ti-corner-left-down',
      'ti-corner-left-down-double',
      'ti-corner-left-up',
      'ti-corner-left-up-double',
      'ti-corner-right-down',
      'ti-corner-right-down-double',
      'ti-corner-right-up',
      'ti-corner-right-up-double',
      'ti-corner-up-left',
      'ti-corner-up-left-double',
      'ti-corner-up-right',
      'ti-corner-up-right-double',
      'ti-crane',
      'ti-credit-card',
      'ti-credit-card-off',
      'ti-crop',
      'ti-crosshair',
      'ti-crown',
      'ti-crown-off',
      'ti-cup',
      'ti-curly-loop',
      'ti-currency-bahraini',
      'ti-currency-bath',
      'ti-currency-bitcoin',
      'ti-currency-cent',
      'ti-currency-dinar',
      'ti-currency-dirham',
      'ti-currency-dollar',
      'ti-currency-dollar-australian',
      'ti-currency-dollar-canadian',
      'ti-currency-dollar-singapore',
      'ti-currency-ethereum',
      'ti-currency-euro',
      'ti-currency-forint',
      'ti-currency-frank',
      'ti-currency-krone-czech',
      'ti-currency-krone-danish',
      'ti-currency-krone-swedish',
      'ti-currency-leu',
      'ti-currency-lira',
      'ti-currency-litecoin',
      'ti-currency-naira',
      'ti-currency-pound',
      'ti-currency-real',
      'ti-currency-renminbi',
      'ti-currency-ripple',
      'ti-currency-riyal',
      'ti-currency-rubel',
      'ti-currency-rupee',
      'ti-currency-shekel',
      'ti-currency-taka',
      'ti-currency-tugrik',
      'ti-currency-won',
      'ti-currency-yen',
      'ti-currency-zloty',
      'ti-current-location',
      'ti-cursor-text',
      'ti-cut',
      'ti-dashboard',
      'ti-database',
      'ti-database-export',
      'ti-database-import',
      'ti-database-off',
      'ti-details',
      'ti-device-analytics',
      'ti-device-audio-tape',
      'ti-device-cctv',
      'ti-device-computer-camera',
      'ti-device-computer-camera-off',
      'ti-device-desktop',
      'ti-device-desktop-analytics',
      'ti-device-desktop-off',
      'ti-device-floppy',
      'ti-device-gamepad',
      'ti-device-laptop',
      'ti-device-mobile',
      'ti-device-mobile-message',
      'ti-device-mobile-rotated',
      'ti-device-mobile-vibration',
      'ti-device-speaker',
      'ti-device-tablet',
      'ti-device-tv',
      'ti-device-watch',
      'ti-devices',
      'ti-devices-2',
      'ti-devices-pc',
      'ti-diamond',
      'ti-dice',
      'ti-dimensions',
      'ti-direction',
      'ti-direction-horizontal',
      'ti-directions',
      'ti-disabled',
      'ti-disabled-2',
      'ti-disc',
      'ti-discount',
      'ti-discount-2',
      'ti-divide',
      'ti-dna',
      'ti-dog-bowl',
      'ti-dots',
      'ti-dots-circle-horizontal',
      'ti-dots-diagonal',
      'ti-dots-diagonal-2',
      'ti-dots-vertical',
      'ti-download',
      'ti-drag-drop',
      'ti-drag-drop-2',
      'ti-drone',
      'ti-drone-off',
      'ti-droplet',
      'ti-droplet-filled',
      'ti-droplet-filled-2',
      'ti-droplet-half',
      'ti-droplet-half-2',
      'ti-droplet-off',
      'ti-ear',
      'ti-ear-off',
      'ti-edit',
      'ti-edit-circle',
      'ti-egg',
      'ti-emphasis',
      'ti-equal',
      'ti-equal-not',
      'ti-eraser',
      'ti-exchange',
      'ti-exposure',
      'ti-external-link',
      'ti-eye',
      'ti-eye-check',
      'ti-eye-off',
      'ti-eyeglass',
      'ti-eyeglass-2',
      'ti-face-id',
      'ti-fall',
      'ti-feather',
      'ti-fence',
      'ti-file',
      'ti-file-alert',
      'ti-file-analytics',
      'ti-file-certificate',
      'ti-file-check',
      'ti-file-code',
      'ti-file-code-2',
      'ti-file-diff',
      'ti-file-dislike',
      'ti-file-download',
      'ti-file-export',
      'ti-file-horizontal',
      'ti-file-import',
      'ti-file-info',
      'ti-file-invoice',
      'ti-file-like',
      'ti-file-minus',
      'ti-file-music',
      'ti-file-off',
      'ti-file-phone',
      'ti-file-plus',
      'ti-file-report',
      'ti-file-search',
      'ti-file-shredder',
      'ti-file-symlink',
      'ti-file-text',
      'ti-file-upload',
      'ti-file-x',
      'ti-file-zip',
      'ti-files',
      'ti-files-off',
      'ti-filter',
      'ti-filter-off',
      'ti-fingerprint',
      'ti-firetruck',
      'ti-fish',
      'ti-flag',
      'ti-flag-2',
      'ti-flag-3',
      'ti-flame',
      'ti-flare',
      'ti-flask',
      'ti-flip-horizontal',
      'ti-flip-vertical',
      'ti-float-center',
      'ti-float-left',
      'ti-float-none',
      'ti-float-right',
      'ti-focus',
      'ti-focus-2',
      'ti-fold',
      'ti-fold-down',
      'ti-fold-up',
      'ti-folder',
      'ti-folder-minus',
      'ti-folder-off',
      'ti-folder-plus',
      'ti-folder-x',
      'ti-folders',
      'ti-forbid',
      'ti-forbid-2',
      'ti-forklift',
      'ti-forms',
      'ti-frame',
      'ti-friends',
      'ti-gas-station',
      'ti-gauge',
      'ti-geometry',
      'ti-ghost',
      'ti-gift',
      'ti-git-branch',
      'ti-git-commit',
      'ti-git-compare',
      'ti-git-fork',
      'ti-git-merge',
      'ti-git-pull-request',
      'ti-glass',
      'ti-glass-full',
      'ti-glass-off',
      'ti-globe',
      'ti-golf',
      'ti-gps',
      'ti-grain',
      'ti-grid-dots',
      'ti-grip-horizontal',
      'ti-grip-vertical',
      'ti-growth',
      'ti-h-1',
      'ti-h-2',
      'ti-h-3',
      'ti-h-4',
      'ti-h-5',
      'ti-h-6',
      'ti-hand-finger',
      'ti-hand-little-finger',
      'ti-hand-middle-finger',
      'ti-hand-off',
      'ti-hand-ring-finger',
      'ti-hand-rock',
      'ti-hand-stop',
      'ti-hand-three-fingers',
      'ti-hand-two-fingers',
      'ti-hanger',
      'ti-hash',
      'ti-heading',
      'ti-headphones',
      'ti-headphones-off',
      'ti-headset',
      'ti-heart',
      'ti-heart-broken',
      'ti-helicopter',
      'ti-helicopter-landing',
      'ti-help',
      'ti-hexagon',
      'ti-hexagon-off',
      'ti-hierarchy',
      'ti-hierarchy-2',
      'ti-history',
      'ti-home',
      'ti-home-2',
      'ti-ice-cream',
      'ti-ice-cream-2',
      'ti-id',
      'ti-inbox',
      'ti-indent-decrease',
      'ti-indent-increase',
      'ti-infinity',
      'ti-info-circle',
      'ti-info-square',
      'ti-italic',
      'ti-jump-rope',
      'ti-karate',
      'ti-key',
      'ti-keyboard',
      'ti-keyboard-hide',
      'ti-keyboard-off',
      'ti-keyboard-show',
      'ti-language',
      'ti-layers-difference',
      'ti-layers-intersect',
      'ti-layers-linked',
      'ti-layers-subtract',
      'ti-layers-union',
      'ti-layout',
      'ti-layout-2',
      'ti-layout-align-bottom',
      'ti-layout-align-center',
      'ti-layout-align-left',
      'ti-layout-align-middle',
      'ti-layout-align-right',
      'ti-layout-align-top',
      'ti-layout-bottombar',
      'ti-layout-cards',
      'ti-layout-columns',
      'ti-layout-distribute-horizontal',
      'ti-layout-distribute-vertical',
      'ti-layout-grid',
      'ti-layout-grid-add',
      'ti-layout-kanban',
      'ti-layout-list',
      'ti-layout-navbar',
      'ti-layout-rows',
      'ti-layout-sidebar',
      'ti-layout-sidebar-right',
      'ti-leaf',
      'ti-lego',
      'ti-lemon',
      'ti-letter-a',
      'ti-letter-b',
      'ti-letter-c',
      'ti-letter-case ',
      'ti-letter-case-lower',
      'ti-letter-case-toggle',
      'ti-letter-case-upper',
      'ti-letter-d',
      'ti-letter-e',
      'ti-letter-f',
      'ti-letter-g',
      'ti-letter-h',
      'ti-letter-i',
      'ti-letter-j',
      'ti-letter-k',
      'ti-letter-l',
      'ti-letter-m',
      'ti-letter-n',
      'ti-letter-o',
      'ti-letter-p',
      'ti-letter-q',
      'ti-letter-r',
      'ti-letter-s',
      'ti-letter-spacing',
      'ti-letter-t',
      'ti-letter-u',
      'ti-letter-v',
      'ti-letter-w',
      'ti-letter-x',
      'ti-letter-y',
      'ti-letter-z',
      'ti-letters-case ',
      'ti-license',
      'ti-lifebuoy',
      'ti-line',
      'ti-line-dashed',
      'ti-line-dotted',
      'ti-line-height',
      'ti-link',
      'ti-list',
      'ti-list-check',
      'ti-list-numbers',
      'ti-list-search',
      'ti-live-photo',
      'ti-live-view',
      'ti-loader',
      'ti-loader-quarter',
      'ti-location',
      'ti-lock',
      'ti-lock-access',
      'ti-lock-off',
      'ti-lock-open',
      'ti-login',
      'ti-logout',
      'ti-macro',
      'ti-magnet',
      'ti-mail',
      'ti-mail-forward',
      'ti-mail-opened',
      'ti-mailbox',
      'ti-man',
      'ti-manual-gearbox',
      'ti-map',
      'ti-map-2',
      'ti-map-pin',
      'ti-map-pin-off',
      'ti-map-pins',
      'ti-markdown',
      'ti-marquee',
      'ti-marquee-2',
      'ti-mars',
      'ti-mask',
      'ti-mask-off',
      'ti-massage',
      'ti-math',
      'ti-math-function',
      'ti-math-symbols',
      'ti-maximize',
      'ti-meat',
      'ti-medal',
      'ti-medical-cross',
      'ti-menu',
      'ti-menu-2',
      'ti-message',
      'ti-message-2',
      'ti-message-circle',
      'ti-message-circle-2',
      'ti-message-circle-off',
      'ti-message-dots',
      'ti-message-off',
      'ti-message-plus',
      'ti-message-report',
      'ti-messages',
      'ti-messages-off',
      'ti-microphone',
      'ti-microphone-2',
      'ti-microphone-off',
      'ti-milk',
      'ti-minimize',
      'ti-minus',
      'ti-minus-vertical',
      'ti-mist',
      'ti-mood-boy',
      'ti-mood-confuzed',
      'ti-mood-crazy-happy',
      'ti-mood-cry',
      'ti-mood-empty',
      'ti-mood-happy',
      'ti-mood-kid',
      'ti-mood-neutral',
      'ti-mood-sad',
      'ti-mood-smile',
      'ti-mood-suprised',
      'ti-mood-tongue',
      'ti-moon',
      'ti-moon-2',
      'ti-moon-stars',
      'ti-moped',
      'ti-motorbike',
      'ti-mouse',
      'ti-movie',
      'ti-mug',
      'ti-mushroom',
      'ti-music',
      'ti-new-section',
      'ti-news',
      'ti-nfc',
      'ti-note',
      'ti-notebook',
      'ti-notes',
      'ti-notification',
      'ti-number-0',
      'ti-number-1',
      'ti-number-2',
      'ti-number-3',
      'ti-number-4',
      'ti-number-5',
      'ti-number-6',
      'ti-number-7',
      'ti-number-8',
      'ti-number-9',
      'ti-octagon',
      'ti-octagon-off',
      'ti-old',
      'ti-olympics',
      'ti-omega',
      'ti-outlet',
      'ti-overline',
      'ti-package',
      'ti-pacman',
      'ti-page-break',
      'ti-paint',
      'ti-palette',
      'ti-panorama-horizontal',
      'ti-panorama-vertical',
      'ti-paperclip',
      'ti-parachute',
      'ti-parentheses',
      'ti-parking',
      'ti-peace',
      'ti-pencil',
      'ti-pennant',
      'ti-pepper',
      'ti-percentage',
      'ti-perspective',
      'ti-phone',
      'ti-phone-call',
      'ti-phone-calling',
      'ti-phone-check',
      'ti-phone-incoming',
      'ti-phone-off',
      'ti-phone-outgoing',
      'ti-phone-pause',
      'ti-phone-plus',
      'ti-phone-x',
      'ti-photo',
      'ti-photo-off',
      'ti-physotherapist',
      'ti-picture-in-picture',
      'ti-picture-in-picture-off',
      'ti-picture-in-picture-on',
      'ti-pill',
      'ti-pin',
      'ti-pinned',
      'ti-pinned-off',
      'ti-pizza',
      'ti-plane',
      'ti-plane-arrival',
      'ti-plane-departure',
      'ti-planet',
      'ti-plant',
      'ti-plant-2',
      'ti-play-card',
      'ti-player-pause',
      'ti-player-play',
      'ti-player-record',
      'ti-player-skip-back',
      'ti-player-skip-forward',
      'ti-player-stop',
      'ti-player-track-next',
      'ti-player-track-prev',
      'ti-playlist',
      'ti-plug',
      'ti-plus',
      'ti-point',
      'ti-pokeball',
      'ti-polaroid',
      'ti-pool',
      'ti-power',
      'ti-pray',
      'ti-presentation',
      'ti-presentation-analytics',
      'ti-printer',
      'ti-prompt',
      'ti-propeller',
      'ti-puzzle',
      'ti-pyramid',
      'ti-qrcode',
      'ti-question-mark',
      'ti-radio',
      'ti-radioactive',
      'ti-radius-bottom-left',
      'ti-radius-bottom-right',
      'ti-radius-top-left',
      'ti-radius-top-right',
      'ti-rainbow',
      'ti-receipt',
      'ti-receipt-2',
      'ti-receipt-off',
      'ti-receipt-refund',
      'ti-receipt-tax',
      'ti-recharging',
      'ti-record-mail',
      'ti-rectangle',
      'ti-rectangle-vertical',
      'ti-recycle',
      'ti-refresh',
      'ti-refresh-alert',
      'ti-registered',
      'ti-relation-many-to-many',
      'ti-relation-one-to-many',
      'ti-relation-one-to-one',
      'ti-repeat',
      'ti-repeat-once',
      'ti-replace',
      'ti-report',
      'ti-report-analytics',
      'ti-report-medical',
      'ti-report-money',
      'ti-resize',
      'ti-ripple',
      'ti-road-sign',
      'ti-rocket',
      'ti-rotate',
      'ti-rotate-2',
      'ti-rotate-clockwise',
      'ti-rotate-clockwise-2',
      'ti-rotate-rectangle',
      'ti-route',
      'ti-router',
      'ti-row-insert-bottom',
      'ti-row-insert-top',
      'ti-rss',
      'ti-ruler',
      'ti-ruler-2',
      'ti-run',
      'ti-sailboat',
      'ti-salt',
      'ti-satellite',
      'ti-sausage',
      'ti-scale',
      'ti-scan',
      'ti-school',
      'ti-scissors',
      'ti-scooter',
      'ti-scooter-electric',
      'ti-screen-share',
      'ti-screen-share-off',
      'ti-scuba-mask',
      'ti-search',
      'ti-section',
      'ti-seeding',
      'ti-select',
      'ti-selector',
      'ti-send',
      'ti-separator',
      'ti-separator-horizontal',
      'ti-separator-vertical',
      'ti-server',
      'ti-servicemark',
      'ti-settings',
      'ti-settings-automation',
      'ti-shadow',
      'ti-shadow-off',
      'ti-shape',
      'ti-shape-2',
      'ti-shape-3',
      'ti-share',
      'ti-shield',
      'ti-shield-check',
      'ti-shield-lock',
      'ti-shield-off',
      'ti-shield-x',
      'ti-ship',
      'ti-shirt',
      'ti-shopping-cart',
      'ti-shopping-cart-discount',
      'ti-shopping-cart-off',
      'ti-shopping-cart-plus',
      'ti-shopping-cart-x',
      'ti-shredder',
      'ti-signature',
      'ti-sitemap',
      'ti-skateboard',
      'ti-slice',
      'ti-slideshow',
      'ti-smart-home',
      'ti-smoking',
      'ti-smoking-no',
      'ti-snowflake',
      'ti-soccer-field',
      'ti-social',
      'ti-sock',
      'ti-sort-ascending',
      'ti-sort-ascending-2',
      'ti-sort-ascending-letters',
      'ti-sort-ascending-numbers',
      'ti-sort-descending',
      'ti-sort-descending-2',
      'ti-sort-descending-letters',
      'ti-sort-descending-numbers',
      'ti-soup',
      'ti-space',
      'ti-speakerphone',
      'ti-speedboat',
      'ti-sport-billard',
      'ti-square',
      'ti-square-0',
      'ti-square-1',
      'ti-square-2',
      'ti-square-3',
      'ti-square-4',
      'ti-square-5',
      'ti-square-6',
      'ti-square-7',
      'ti-square-8',
      'ti-square-9',
      'ti-square-check',
      'ti-square-dot',
      'ti-square-forbid',
      'ti-square-forbid-2',
      'ti-square-minus',
      'ti-square-off',
      'ti-square-plus',
      'ti-square-root',
      'ti-square-root-2',
      'ti-square-rotated',
      'ti-square-rotated-off',
      'ti-square-toggle',
      'ti-square-toggle-horizontal',
      'ti-square-x',
      'ti-squares-diagonal',
      'ti-squares-filled',
      'ti-stack',
      'ti-stack-2',
      'ti-stairs',
      'ti-stairs-down',
      'ti-stairs-up',
      'ti-star',
      'ti-star-half',
      'ti-star-off',
      'ti-stars',
      'ti-steering-wheel',
      'ti-step-into',
      'ti-step-out',
      'ti-stethoscope',
      'ti-sticker',
      'ti-strikethrough',
      'ti-submarine',
      'ti-subscript',
      'ti-subtask',
      'ti-sum',
      'ti-sun',
      'ti-sun-off',
      'ti-sunrise',
      'ti-sunset',
      'ti-superscript',
      'ti-swimming',
      'ti-switch',
      'ti-switch-2',
      'ti-switch-3',
      'ti-switch-horizontal',
      'ti-switch-vertical',
      'ti-table',
      'ti-table-export ',
      'ti-table-import ',
      'ti-table-off',
      'ti-tag',
      'ti-tallymark-1',
      'ti-tallymark-2',
      'ti-tallymark-3',
      'ti-tallymark-4',
      'ti-tallymarks',
      'ti-tank',
      'ti-target',
      'ti-temperature',
      'ti-temperature-celsius',
      'ti-temperature-fahrenheit',
      'ti-temperature-minus',
      'ti-temperature-plus',
      'ti-template',
      'ti-tent',
      'ti-terminal',
      'ti-terminal-2',
      'ti-test-pipe',
      'ti-text-direction-ltr',
      'ti-text-direction-rtl',
      'ti-text-wrap',
      'ti-text-wrap-disabled',
      'ti-thumb-down',
      'ti-thumb-up',
      'ti-ticket',
      'ti-tilt-shift',
      'ti-tir',
      'ti-toggle-left',
      'ti-toggle-right',
      'ti-tool',
      'ti-tools',
      'ti-tools-kitchen',
      'ti-tools-kitchen-2',
      'ti-tornado',
      'ti-tournament',
      'ti-track',
      'ti-tractor',
      'ti-trademark',
      'ti-traffic-cone',
      'ti-traffic-lights',
      'ti-train',
      'ti-transfer-in ',
      'ti-transfer-out',
      'ti-trash',
      'ti-trash-off',
      'ti-tree',
      'ti-trees',
      'ti-trending-down',
      'ti-trending-down-2',
      'ti-trending-down-3',
      'ti-trending-up',
      'ti-trending-up-2',
      'ti-trending-up-3',
      'ti-triangle',
      'ti-triangle-off',
      'ti-triangle-square-circle',
      'ti-trident',
      'ti-trophy',
      'ti-truck',
      'ti-truck-delivery',
      'ti-truck-off',
      'ti-truck-return ',
      'ti-typography',
      'ti-umbrella',
      'ti-underline',
      'ti-unlink',
      'ti-upload',
      'ti-urgent',
      'ti-user',
      'ti-user-check',
      'ti-user-exclamation',
      'ti-user-minus',
      'ti-user-off',
      'ti-user-plus',
      'ti-user-x',
      'ti-users',
      'ti-vaccine',
      'ti-variable',
      'ti-vector',
      'ti-vector-beizer-2',
      'ti-vector-bezier',
      'ti-vector-triangle',
      'ti-venus',
      'ti-versions',
      'ti-video',
      'ti-video-minus',
      'ti-video-off',
      'ti-video-plus',
      'ti-view-360',
      'ti-viewfinder',
      'ti-viewport-narrow',
      'ti-viewport-wide',
      'ti-virus',
      'ti-virus-off',
      'ti-virus-search',
      'ti-vocabulary',
      'ti-volume',
      'ti-volume-2',
      'ti-volume-3',
      'ti-walk',
      'ti-wallet',
      'ti-wand',
      'ti-wave-saw-tool',
      'ti-wave-sine',
      'ti-wave-square',
      'ti-wifi',
      'ti-wifi-0',
      'ti-wifi-1',
      'ti-wifi-2',
      'ti-wifi-off',
      'ti-wind',
      'ti-windmill',
      'ti-window',
      'ti-wiper',
      'ti-wiper-wash',
      'ti-woman',
      'ti-world',
      'ti-world-latitude',
      'ti-world-longitude',
      'ti-wrecking-ball',
      'ti-writing',
      'ti-writing-sign',
      'ti-x',
      'ti-yin-yang',
      'ti-zodiac-aquarius',
      'ti-zodiac-aries',
      'ti-zodiac-cancer',
      'ti-zodiac-capricorn',
      'ti-zodiac-gemini',
      'ti-zodiac-leo',
      'ti-zodiac-libra',
      'ti-zodiac-pisces',
      'ti-zodiac-sagittarius',
      'ti-zodiac-scorpio',
      'ti-zodiac-taurus',
      'ti-zodiac-virgo',
      'ti-zoom-cancel',
      'ti-zoom-check',
      'ti-zoom-in',
      'ti-zoom-money',
      'ti-zoom-out',
      'ti-zoom-question'
    ];

    for (var i = 0, l = icon_list.length; i < l; i++) {
      let icon_block = document.createElement('div');
      icon_block.setAttribute('class', 'i-block');
      icon_block.setAttribute('data-clipboard-text', 'ti ' + icon_list[i]);
      icon_block.setAttribute('data-bs-toggle', 'tooltip');
      icon_block.setAttribute('data-filter', icon_list[i]);
      icon_block.setAttribute('title', 'ti ' + icon_list[i]);

      let icon_main = document.createElement('i');
      icon_main.setAttribute('class', 'ti ' + icon_list[i]);
      icon_block.appendChild(icon_main);
      document.querySelector('#icon-wrapper').append(icon_block);
    }
    window.addEventListener('load', (event) => {
      var i_clip = new ClipboardJS('.i-block');
      i_clip.on('success', function (e) {
        var targetElement = e.trigger;
        let icon_badge = document.createElement('span');
        icon_badge.setAttribute('class', 'ic-badge badge bg-success');
        icon_badge.innerHTML = 'copied';
        targetElement.append(icon_badge);
        setTimeout(function () {
          targetElement.children[1].remove();
        }, 3000);
      });

      i_clip.on('error', function (e) {
        var targetElement = e.trigger;
        let icon_badge = document.createElement('span');
        icon_badge.setAttribute('class', 'ic-badge badge bg-danger');
        icon_badge.innerHTML = 'Error';
        targetElement.append(icon_badge);
        setTimeout(function () {
          targetElement.children[1].remove();
        }, 3000);
      });
      document.querySelector('#icon-search').addEventListener('keyup', function () {
        var g = document.querySelector('#icon-search').value.toLowerCase();
        var tc = document.querySelectorAll('.i-main .i-block');
        for (var i = 0; i < tc.length; i++) {
          var c = tc[i];
          var t = c.getAttribute('data-filter');
          if (t) {
            var s = t.toLowerCase();
          }
          if (s) {
            var n = s.indexOf(g);
            if (n !== -1) {
              c.style.display = 'inline-flex';
            } else {
              c.style.display = 'none';
            }
          }
        }
      });
    });
  </script>
{% endblock extra_js %}
