{% load static %}

<!-- [Favicon] icon -->
<link rel="icon" href="{% static 'assets/images/favicon.svg' %}" type="image/x-icon" />
<!-- [Google Font] Family -->
<link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500;700&display=swap" id="main-font-link" />
<!-- [Tabler Icons] https://tablericons.com -->
<link rel="stylesheet" href="{% static 'assets/fonts/tabler-icons.min.css' %}" />
<!-- [Material Icons] https://fonts.google.com/icons -->
<link rel="stylesheet" href="{% static 'assets/fonts/material.css' %}" />
<!-- [Template CSS Files] -->
<link rel="stylesheet" href="{% static 'assets/css/style.css' %}" id="main-style-link" />
<link rel="stylesheet" href="{% static 'assets/css/style-preset.css' %}" id="preset-style-link" />